########################################################
###################### readme first ####################
########################################################
#
#
#This file contains all the commands of our MACSE tutorial paper published in Methods in Molecular Biology
#It is part of an archive that contains: 
#   i) the macse_v2.03.jar program
#  ii) this command file 
# iii) several subfolders containing the input files for the different command line examples
#
#
#In the tutorial paper, to enhance readibility, we assume that MACSE can be launch using 
#       "java -jar macse.jar" 
#This will here be replaced either by 
#      "java -jar macse_v2.03.jar" if the command is launched from the main directory where the macse_v2.03.jar file actually is
#  or  "java -jar ../macse_v2.03.jar" if the command is launched from a subfolder containing some required input files
#
#
#Some examples are fast, others take longer and are indicated as such using:"(longer)"
#
#The singularity containers are large files not included in this archive and should be downloaded separately from the MACSE website to be able to execute the corresponding example commands (EX9 and EX10).
# 
#Comments start by this "#" symbol


##########################################################
#### basic commands to execute from the main directory
#### "2.1 getting started"
##########################################################

#Launch the GUI version of MACSE.
java -jar macse_v2.03.jar

#Launch the command line version of MACSE, and print a help message listing all valid subprograms with a one-line description of each of them.
java -jar macse_v2.03.jar -prog wrongProgram


#Print a basic help message of the alignSequences subprogram focusing on its mandatory options.
java -jar macse_v2.03.jar -prog alignSequences


#Print a detailed help message of the alignSequences subprogram presenting all available options.
java -jar macse_v2.03.jar -prog alignSequences -help


###########################################################
#### more advanced commands to execute from the subfolders
#### hence the use of "../" to specify that macse_v2.03.jar
#### is in the parent directory not in the current one 
###########################################################

###########################################################
### 2.2 Obtaining suitable input sequences
###     EX1_GZF1_trimNonHomologous subfolder
###########################################################

#Prefilter long nonhomologous sequence fragments; if more than 60% of a sequence is filtered then this sequence is entirely removed.
java -jar ../macse_v2.03.jar -prog trimNonHomologousFragments -seq ENSG00000125812_GZF1_raw.fasta -out_trim_info output_stats.csv -min_homology_to_keep_seq 0.6

###########################################################
### 2.3 Most common usages
###########################################################

###-----------------------------------------------------###
### EX2_PG3_alignSequences subfolder
###-----------------------------------------------------###
#Align sequences contained in the Pg3_Medicago.fasta file with default parameters (Figure 1).
java -jar ../macse_v2.03.jar -prog alignSequences -seq Pg3_Medicago.fasta


###-----------------------------------------------------###
### EX3_COX1_gc_def subfolder
###-----------------------------------------------------###
#Align invertebrate mitochondrial sequences with the specified genetic code “5”.
java -jar ../macse_v2.03.jar -prog alignSequences -seq grasshoppers_COX1.fasta -gc_def 5

###-----------------------------------------------------###
### EX4_COX1_gc_file subfolder (takes longer)
###-----------------------------------------------------###
#Align metazoan mitochondrial sequences with their corresponding genetic codes (Figure 3).
java -jar ../macse_v2.03.jar -prog alignSequences -seq Singh2009_cox1.fasta -gc_file Singh2009_cox1_gc_file.txt -out_NT Singh2009_cox1_NT.fasta -out_AA Singh2009_cox1_AA.fasta

###-----------------------------------------------------###
### EX5_COX1_gc_file_translate subfolder
###-----------------------------------------------------###
#Translate metazoan mitochondrial sequences with their corresponding genetic codes.
java -jar ../macse_v2.03.jar -prog translateNT2AA -seq Singh2009_cox1.fasta -gc_file Singh2009_cox1_gc_file.txt

###-----------------------------------------------------###
### EX6_CHIA4_pseudogenes_cost_FS subfolder
###-----------------------------------------------------###
#Align a mix of functional CDS and pseudogenes (Figure 4).
java -jar ../macse_v2.03.jar -prog alignSequences -seq Emerling2018_CHIA4_functional.fasta -seq_lr Emerling2018_CHIA4_pseudo.fasta -fs_lr 10 -stop_lr 10 -out_NT Emerling2018_CHIA4_NT.fasta -out_AA Emerling2018_CHIA4_AA.fasta

###########################################################
### 3.2 Basic pipelines and batch facilities
###########################################################

###-----------------------------------------------------###
### EX7_LOC_XXX_multiprograms subfolder (longer)
###-----------------------------------------------------###

#Launch all MACSE commands stored in the align_multi.macse file.
java -jar ../macse_v2.03.jar -prog multiPrograms -MACSE_command_file align_multi.macse
# with align_multi.macse containing the following lines
#-prog alignSequences -seq LOC_19470.fasta
#-prog alignSequences -seq LOC_48720.fasta
#-prog alignSequences -seq LOC_72220.fasta

###-----------------------------------------------------###
### ...or from the main folder using the "@" symbol (longer) 
###-----------------------------------------------------###
java -jar macse_v2.03.jar -prog multiPrograms -MACSE_command_file EX7b_LOC_XXX_multiprogramsAt/align_multiAt.macse

#with EX7b_LOC_XXX_multiprogramsAt/align_multiAt.macse containing the following lines
#-prog alignSequences -seq @LOC_19470.fasta
#-prog alignSequences -seq @LOC_48720.fasta
#-prog alignSequences -seq @LOC_72220.fasta

###########################################################
### 3.3 Aligning dozens of sequences
###########################################################

###-----------------------------------------------------###
### EX8_PG3_alignLargerDataset_Xmx subfolder
###-----------------------------------------------------###

#Align larger datasets by allocating more memory to Java using the Xmx option
#The most simple MACSE use case.
java -jar –Xmx 600m ../macse_v2.03.jar -prog alignSequences -seq Pg3_Medicago.fasta

###-----------------------------------------------------###
### EX9_LOC_48720_ALFIX_pipeline subfolder
###-----------------------------------------------------###

#The most simple use case of the MACSE_ALFIX pipeline
singularity run ./MACSE_ALFIX_v01.sif  --in_seq_file LOC_48720.fasta --out_dir RES_LOC_48720 --out_file_prefix LOC_48720

###########################################################
### 3.4 Aligning hundreds of sequences
###########################################################

###-----------------------------------------------------###
### EX10_LOC_48720_OMM_MACSE_pipeline
###-----------------------------------------------------###

#The most simple use case of the OMM_MACSE pipeline for larger datasets
singularity run ./OMM_MACSE_v10.01.sif --in_seq_file LOC_48720.fasta --out_dir RES_LOC_48720 --out_file_prefix LOC_48720

###########################################################
### 3.5 Aligning thousands of sequences
###########################################################

###-----------------------------------------------------###
### EX11_alignTwoProfiles subfolder
###-----------------------------------------------------###

#Aligns two previously computed alignments.
#Here afrotherian (align1) vs other mammals (align2) for gene STL7
java -jar ../macse_v2.03.jar -prog alignTwoProfiles -p1 align1.fasta -p2 align2.fasta

###-----------------------------------------------------###
### EX12_alignTwoProfilesMulti subfolder
###-----------------------------------------------------###
#Basic strategy to align four previously computed alignments.
#example files are here really small just to illustrate the principle
java -jar ../macse_v2.03.jar -prog multiPrograms -MACSE_command_file align_multi.macse

#where align_multi.macse is a text file containing these four lines:
#-prog alignTwoProfiles -p1 ali1.fasta     -p2 ali2.fasta -out_NT ali12.fasta
#-prog alignTwoProfiles -p1 ali12.fasta    -p2 ali3.fasta -out_NT ali123.fasta
#-prog alignTwoProfiles -p1 ali123.fasta   -p2 ali4.fasta -out_NT ali_All.fasta


###########################################################
### 3.6 Metabarcoding applications
###########################################################

###-----------------------------------------------------###
### EX13_BARCODE_enrichAlignment subfolder
###-----------------------------------------------------###

#Enrich an initial alignment by conditionally adding sequences to it.
java -jar ../macse_v2.03.jar -prog enrichAlignment -align Moorea_BIOCODE_small_ref.fasta -seq Moorea_BIOCODE_small_ref.fasta -seq_lr noctural_diet_sample.fasta -gc_def 5 -fs_lr 10 -stop_lr 10 -maxFS_inSeq 0 -maxINS_inSeq 0 -maxSTOP_inSeq 1
